<!-- Bootstrap CSS -->
<link href="{{pathto('_static/css/bootstrap.min.css', 1)}}" rel="stylesheet">

<!-- Pygments CSS -->
<link href="{{pathto('_static/css/native.css', 1)}}" rel="stylesheet">

<!-- Fonts -->
<link href="{{pathto('_static/css/font-awesome.min.css', 1)}}" rel="stylesheet">

<!-- Custom CSS -->
<link href="{{pathto('_static/css/combined.css', 1)}}" rel="stylesheet">

<!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
<!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
<!--[if lt IE 9]>
    <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
    <script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>
<![endif]-->
