{% if page_source_suffix %}{# an input file was read #}
<!-- SOURCE_FILE: {% if giturl %}{{giturl}}/{% endif %}{{pagename}}{{page_source_suffix}} -->
{% else %}{# a template was rendered directly #}
<!-- TEMPLATE_NAME: {{pagename}} -->
{% endif %}
<nav class="navbar navbar-default" role="navigation">
  <div class="container">
    <!-- Brand and toggle get grouped for better mobile display -->
    <div class="navbar-header">
      <button class="navbar-toggle" data-target="#bs-example-navbar-collapse-1" data-toggle="collapse" type="button">
        <span class="sr-only">Toggle navigation</span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
      </button>
      <div class="brand-wrapper">
        <a class="navbar-brand" href="https://cloud.telekom.de/en/infrastructure/open-telekom-cloud/"></a>
      </div>
      <!-- <div class="search-icon show"><i class="fa fa-search"></i> Search</div> -->
    </div>
    <div class="collapse navbar-collapse" id="bs-example-navbar-collapse-1">
      <div class="search-container tiny">
         <!-- {% include 'swiftype_search.html' %} -->
        <i class="fa fa-times close-search"></i>
      </div>
      <ul class="nav navbar-nav navbar-main show">
        <!-- <li>
           {% include 'swiftype_search_mobile.html' %}
        </li> -->
        <li>
          <a href="" class="drop" id="dropdownMenuSoftware">Software <i class="fa fa-caret-down"></i></a>
          <ul class="dropdown-menu" role="menu" aria-labelledby="dropdownMenuSoftware">
            <li role="presentation"><a role="menuitem" tabindex="-1" href="">Overview</a></li>
            <li role="presentation"><a role="menuitem" tabindex="-1" href="https://github.com/opentelekomcloud/openstacksdk">OpenStackSDK Extensions</a></li>
            <li role="presentation" class="divider"></li>
          </ul>
        </li>
        <li>
          <a href="" class="drop" id="dropdownMenuLearn">Learn <i class="fa fa-caret-down"></i></a>
          <ul class="dropdown-menu dropdown-hover" role="menu" aria-labelledby="dropdownMenuEvents">
            <li role="presentation"><a role="menuitem" tabindex="-1" href="https://opentelekomcloud.github.io/techblog/">Blog</a></li>
          </ul>
        </li>
        <li>
          <a href="https://docs.otc.t-systems.com/">Docs</a>
        </li>
        <li>
        </li>
      </ul>
    </div>
  </div>
  <!-- /.container -->
</nav>
